/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
/* eslint-disable react/sort-prop-types */

import L from 'leaflet';
import 'leaflet/dist/leaflet.css';
import 'leaflet.markercluster/dist/MarkerCluster.css';
import 'leaflet.markercluster/dist/MarkerCluster.Default.css';
import 'leaflet.markercluster';
import {v4 as uuidv4} from 'uuid';
import PropTypes from 'prop-types';

function HexCode(rgba){
  const hex = `#${((1 << 24) + (rgba['r'] << 16) + (rgba['g'] << 8) + rgba['b']).toString(16).slice(1)}`;
  return hex;
}

const propTypes = {
  data: PropTypes.arrayOf(
    PropTypes.shape({
      country_id: PropTypes.string,
      metric: PropTypes.number,
    }),
  ),
  width: PropTypes.number,
  height: PropTypes.number,
  country: PropTypes.string,
  linearColorScheme: PropTypes.string,
  mapBaseUrl: PropTypes.string,
  numberFormat: PropTypes.string,
};

var map;

function CountryMap(element, props) {
  const { data, width, height, state, pointRadiusFixed, LAT, LON, targetColorPicker } = props;

  // console.log(data)
  const container = element;
  const keys = Object.keys(data[0]);
  const metric = keys[2];

  // const div = L.select(container);
  // yield container;
  if(map != undefined){
    map.off();
    map.remove();
  }
  map = L.map(container, {minZoom: 2, zoomDelta: 0.25, zoomSnap: 0});
  
  //Bounding box
  var lat_min = data.reduce((prev, cur) => prev[LAT] < cur[LAT] ? prev : cur)[LAT];
  var lat_max = data.reduce((prev, cur) => prev[LAT] > cur[LAT] ? prev : cur)[LAT];
  var lon_min = data.reduce((prev, cur) => prev[LON] < cur[LON] ? prev : cur)[LON];
  var lon_max = data.reduce((prev, cur) => prev[LON] > cur[LON] ? prev : cur)[LON];
  
  console.log(lat_min, lat_max, lon_min, lon_max);
  
  const corner1 = L.latLng(lat_min, lon_min);
  const corner2 = L.latLng(lat_max, lon_max);
  const bounds = L.latLngBounds(corner1, corner2);
  map.on("load", function() { setTimeout(() => {map.invalidateSize(); map.fitBounds(bounds);}, 0); });
  
  // map.setView([22, 77], 4);
  map.fitBounds(bounds);
  // console.log(height, width)
  container.style.height = `${height}px`;
  container.style.width = `${width}px`;
  
  // const mapLink = '<a href="http://openstreetmap.org">OpenStreetMap</a>';
  L.tileLayer('https://{s}.tile.openstreetmap.org/{z}/{x}/{y}.png', {
  	maxZoom: 18,
	  attribution: '&copy; <a href="https://www.openstreetmap.org/copyright">OpenStreetMap</a> contributors',
  }).addTo(map);
  
  var markers = new L.MarkerClusterGroup({
    key : uuidv4(),
  });
  
  data.forEach((point) => {
    var circle = L.circle([point[LAT], point[LON]], {
      color: HexCode(targetColorPicker),
      fillOpacity: 0.5,
      radius: metric ? point[metric]: pointRadiusFixed.value,
      // radius: 500,
    });
    circle.bindTooltip("Longitude: " + point[LON] + " E" + "<br>" + "Latitude: " + point[LAT] + " N" + "<br>" + "Radius : " + (metric ? point[metric]: pointRadiusFixed.value),{
      direction : 'top',
    })
    markers.addLayer(circle);
  });
  map.addLayer(markers);
}

CountryMap.displayName = 'CountryMap';
CountryMap.propTypes = propTypes;

export default CountryMap;
