/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
import { t, validateNonEmpty } from '@superset-ui/core';
import {
  ControlPanelConfig,
  sections,
  columnChoices
} from '@superset-ui/chart-controls';
// import { stateOptions } from './stateNames';

const config: ControlPanelConfig = {
  controlPanelSections: [
    sections.legacyRegularTime,
    {
      label: t('Query'),
      expanded: true,
      controlSetRows: [
        [
          {
            name: 'spatial',
            config: {
              type: 'SpatialControl',
              label: t('Longitude & Latitude'),
              validators: [validateNonEmpty],
              description: t('Point to your spatial columns'),
              mapStateToProps: state => ({
                choices: columnChoices(state.datasource),
              }),
            },
          }
        ],
        [
          {
            name: 'point_radius_fixed',
            config: {
              type: 'FixedOrMetricControl',
              label: t('Point Size'),
              default: { type: 'fix', value: 10 },
              description: t('Fixed point radius'),
              mapStateToProps: state => ({
                datasource: state.datasource,
              }),
            },
          }
        ],
        ['adhoc_filters'],
        ['row_limit'],
        [
          {
            name: 'target_color_picker',
            config: {
              label: t('Target Color'),
              description: t('Color of the target location'),
              type: 'ColorPickerControl',
              default: {r:256, g:0, b:0, a:1.0},
              renderTrigger: true,
            },
          }
        ]
      ],
    },
  ],
  controlOverrides: {
    // entity: {
    //   label: t('ISO 3166-2 Codes'),
    //   description: t(
    //     'Column containing ISO 3166-2 codes of region/province/department in your table.',
    //   ),
    // },
    // metric: {
    //   label: t('Point Radius'),
    //   description: 'Radius of the point depends on size of the metric',
    // },
    linear_color_scheme: {
      renderTrigger: false,
    },
    row_limit:{
      default: 1000,
    },
  },
};

export default config;
